command

package
v0.0.0-...-bdb1de1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 26, 2015 License: MIT Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type IndexCommand

type IndexCommand struct {
	UI cli.Ui
}

IndexCommand is a Command implementation that says hello world

func (*IndexCommand) Help

func (c *IndexCommand) Help() string

Help prints the help text for the run sub-command.

func (*IndexCommand) Run

func (c *IndexCommand) Run(args []string) int

Run runs the index command; optionally, the config file can be added.

func (*IndexCommand) Synopsis

func (c *IndexCommand) Synopsis() string

Synopsis provides a precis of the index command.

type VersionCommand

type VersionCommand struct {
	Name              string
	Revision          string
	Version           string
	VersionPrerelease string
	UI                cli.Ui
}

VersionCommand is a Command implementation that prints the version.

func (*VersionCommand) Help

func (c *VersionCommand) Help() string

Help prints the Help text for the version sub-command

func (*VersionCommand) Run

func (c *VersionCommand) Run(_ []string) int

Run runs the version sub-command.

func (*VersionCommand) Synopsis

func (c *VersionCommand) Synopsis() string

Synopsis provides a precis of the version sub-command.

Jump to